#!/bin/sh
DAEMON=/usr/bin/orwell
ORWELLPATH=/usr/lib/enigma2/python/Plugins/Extensions/Orwell
ORWELLSH="/etc/init.d/orwell.sh"
NAME=orwell
DESC="Orwell Permanent Recording"
SEC=3
LOG=/tmp/orwell.log
RUNNING=/tmp/.orwellrunning
LINE="--------------------------------------------------------------------------------"
LIMIT=4000
NUMBER=4
TIMEOUT=10
RECORDPATH=/media/hdd
if [ -f $ORWELLPATH/.orwelllimit ]; then
   LIMIT=`cat $ORWELLPATH/.orwelllimit`
fi
if [ -f $ORWELLPATH/.orwellnumber ]; then
   NUMBER=`cat $ORWELLPATH/.orwellnumber`
fi
if [ -f $ORWELLPATH/.orwelltimeout ]; then
   TIMEOUT=`cat $ORWELLPATH/.orwelltimeout`
fi
ALWAYS=""
if [ -f $ORWELLPATH/.orwellalways  ]; then
   ALWAYS="-o"
fi
EPGSPLIT=""
if [ -f $ORWELLPATH/.orwellepgsplit  ]; then
   EPGSPLIT="-e"
fi
if [ -f $ORWELLPATH/.orwellpath ]; then
   RECORDPATH=`cat $ORWELLPATH/.orwellpath`
fi
if [ ! -d "$RECORDPATH/movie" ]; then
   mkdir "$RECORDPATH/movie" 
fi
DEBUG=""
if [ -f $ORWELLPATH/.orwelldebug ]; then
   DEBUG="-d"
fi


case "$1" in
    start)
        echo $LINE
        if [ $# -gt 1 ]; then
           CHANNEL=$2
        fi
        CHECK=`ps ax | grep $DAEMON | wc -l`
#       echo $CHECK
        if [ $CHECK -gt 1 ]; then
           echo "$DESC already running, use stop to restart"
           echo $LINE
           exit 1
        fi
        if [ -f $RUNNING ]; then
           rm $RUNNING 
        fi
        kill $(pidof orwell) > /dev/null 2>&1
        # wait until orwell.sh loop dies	   
        echo "$DESC is first stopped to prevent problems"
        echo $LINE
	sleep $SEC
        touch $RUNNING
        echo "starting $DESC"
        if [ $# -gt 1 ]; then
	   nohup $ORWELLSH loop $CHANNEL >> $LOG &
	else
	   nohup $ORWELLSH loop >> $LOG &
	fi
        echo $LINE
	;;
    stop)
        if [ -f $RUNNING ]; then
           rm $RUNNING 
        fi
        echo $LINE
        echo "stopping $DESC"
        echo $LINE
	kill $(pidof orwell) > /dev/null 2>&1
        # wait until orwell.sh loop dies	   
	sleep 5
	killall -9 $ORWELLSH > /dev/null 2>&1
	;;
    check)
        echo $LINE
        echo "$DESC file size   limit:     $LIMIT MB"
        echo $LINE
        echo "$DESC file number limit:     $NUMBER"
        echo $LINE
        echo "$DESC timeout:               $TIMEOUT sec"
        echo $LINE
        if [ -f $ORWELLPATH/.orwellenabled  ]; then
           echo "$DESC is enabled on boot"
        else
           echo "$DESC is disabled on boot"
        fi
        echo $LINE
        if [ -f $ORWELLPATH/.orwellalways  ]; then
           echo "$DESC is enabled on standby"
        else
           echo "$DESC is disabled on standby"
        fi
        echo $LINE
        if [ -f $ORWELLPATH/.orwellepgsplit  ]; then
           echo "$DESC has epg split disabled"
        else
           echo "$DESC has epg split enabled"
        fi
        echo $LINE
        if [ -f $ORWELLPATH/.orwelldebug ]; then
           echo "$DESC has debug enabled"
        else
           echo "$DESC has debug disabled"
        fi
        echo $LINE
        echo "$DESC records on $RECORDPATH"
        echo $LINE
        if [ `ps ax | grep $DAEMON | wc -l` -gt 1 ]; then
           echo "$DESC: $DAEMON is running"
           echo $LINE
           ps ax | grep $DAEMON | grep -v grep
        else
           echo "$DESC: $DAEMON is NOT running"
        fi
        echo $LINE
	;;
    loop)
        touch $RUNNING
        while [ $SEC -gt 0 ]; do
        if [ `ps ax | grep $DAEMON | wc -l` -gt 1 ]; then
           sleep $SEC
        else
           if [ -f $RUNNING ]; then
#             sleep $SEC
              if [ `ps ax | grep enigma2 | wc -l` -gt 2 ]; then
                 if [ $# -lt 2 ]; then
                    nohup $DAEMON -l $LIMIT -n $NUMBER -p $RECORDPATH -t $TIMEOUT $ALWAYS $EPGSPLIT $DEBUG >> $LOG &
                 else
                    nohup $DAEMON -l $LIMIT -n $NUMBER -p $RECORDPATH -s $2 -t $TIMEOUT $ALWAYS $EPGSPLIT $DEBUG >> $LOG &
                 fi
              fi
           else
              # master wants me to die ...
              exit 0
           fi
        fi 
        done
    ;;
    *)
	echo "Usage: $0 {start|stop|check|loop}"
        echo $LINE
	exit 1
	;;
esac
exit 0
