# -*- coding: utf-8 -*-
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from ServiceReference import ServiceReference
from Plugins.Plugin import PluginDescriptor
from Screens.ImageWizard import ImageWizard
from enigma import eConsoleAppContainer

import os

orwell_plugindir="/usr/lib/enigma2/python/Plugins/Extensions/Orwell"

# versionstring, please do not change, if you do not release a new version
orwell_version = "0.9"

# path to the standard readme-file
orwell_readme = "%s/readme.txt" % orwell_plugindir

# path to the orwell.sh
orwell_script = "/etc/init.d/orwell.sh" 

# paths to config files
orwell_enabled = "%s/.orwellenabled" % orwell_plugindir
orwell_always = "%s/.orwellalways" % orwell_plugindir
orwell_epgsplit = "%s/.orwellepgsplit" % orwell_plugindir
orwell_debug = "%s/.orwelldebug" % orwell_plugindir
orwell_limit = "%s/.orwelllimit" % orwell_plugindir
orwell_number = "%s/.orwellnumber" % orwell_plugindir
orwell_timeout = "%s/.orwelltimeout" % orwell_plugindir
orwell_path = "%s/.orwellpath" % orwell_plugindir

def main(session,**kwargs):
    session.open(Orwell)


def autostart(reason, **kwargs):
    pass
    
    if "session" in kwargs:
       OrwellStartup(kwargs["session"])
	
def Plugins(**kwargs):
    return [PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART, PluginDescriptor.WHERE_AUTOSTART], fnc = autostart),PluginDescriptor(name="Orwell", description="Permanent Recording", where = PluginDescriptor.WHERE_PLUGINMENU, icon="orwell.png", fnc=main),
			PluginDescriptor(name="Orwell", description=_("Permanent Recording Daemon"), where = PluginDescriptor.WHERE_EXTENSIONSMENU, icon="orwell.png", fnc=main)]

class Orwell(Screen):
    skin = """
        <screen position="150,100" size="400,300" title="Orwell Menu" >
            <widget name="menu" position="10,10" size="390,290" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = Orwell.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        orwell = []
        orwell.append((_("Check Orwell Daemon and Settings"), "check"))
        orwell.append((_("Start Orwell Daemon"), "start"))
        orwell.append((_("Stop  Orwell Daemon"), "stop"))
        orwell.append((_("Permanent Record Current Channel"), "record"))
        orwell.append((_("Permanent Recording Settings"), "settings"))        
        orwell.append((_("Show  readme.txt"), "readme"))        
        orwell.append((_("about"), "about"))        
        self["menu"] = MenuList(orwell)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "readme":
              self.session.open(Console,_("Orwell readme.txt"),["cat %s" % orwell_readme])
           elif returnValue is "record":
              RecordCurrentChannel(self.session)
           elif returnValue is "settings":
              OrwellSettings(self.session)
           elif returnValue is "enable":
              os.system("touch %s" % orwell_enabled)
              self.session.open(MessageBox,("Permanent Recording enabled on boot"),  MessageBox.TYPE_INFO, timeout=5)
           elif returnValue is "disable":
              if os.path.exists(orwell_enabled) == True:
                 os.system("rm %s" % orwell_enabled)
              self.session.open(MessageBox,("Permanent Recording disabled on boot"),  MessageBox.TYPE_INFO, timeout=5)
           elif returnValue is "about":
              title=_("Orwell Permanent Recording Plugin\nVersion %s by gutemine") % (orwell_version)
              self.session.open(MessageBox,("%s") % (title),  MessageBox.TYPE_INFO)
           else:
              title = _("executing %s") %(returnValue)
              cmd = "%s %s" % (orwell_script,returnValue)
              self.session.open(Console,_(title),[cmd])
              
class OrwellStartup(Screen):
	def __init__(self,session):
		Screen.__init__(self,session)

		self.session = session
                if os.path.exists(orwell_enabled) == True:
   		   self.TimerOrwellStartup = eTimer()
		   self.TimerOrwellStartup.stop()
		   self.TimerOrwellStartup.timeout.get().append(self.CheckOrwellStartup)
		   self.TimerOrwellStartup.start(10000,True) 
		   
	def CheckOrwellStartup(self):
		self.TimerOrwellStartup.stop()
		self.session.openWithCallback(self.DoOrwellStartup,MessageBox,"Start Orwell Permanent Recording - OK ?",type = MessageBox.TYPE_YESNO,timeout = 10)		


        def DoOrwellStartup(self,retval):
		if (retval):
                   title = _("starting Orwell Permanent Recording on boot") 
                   cmd = "%s start" % (orwell_script)
                   self.session.open(Console,_(title),[cmd])
                else:
                   self.session.open(MessageBox,("Permanent Recording NOT started on boot\nUse Orwell Plugin to start later"),  MessageBox.TYPE_INFO, timeout=5)
                   
        
class RecordCurrentChannel(Screen):
    def __init__(self, session):

        self.session = session
        self.askForRecordChannel()

    def askForRecordChannel(self):
        self.session.openWithCallback(self.DoRecordChannel,MessageBox,_("Permanent Record for Current Channel ?"), MessageBox.TYPE_YESNO)

    def DoRecordChannel(self,answer):
        if answer is None:
           self.skipRecordCurrentChannel("answer is None")
        if answer is False:
           self.skipRecordCurrentChannel("you were not confirming")
        else:
           servname = "%s" % ServiceReference(self.session.nav.getCurrentlyPlayingServiceReference())
	   if servname.startswith("1:0:0:0:0:0:0:0:0:0") is True:
              self.session.open(MessageBox,_("currently no live channel to record, sorry !"), MessageBox.TYPE_INFO)
           else:
              title = _("starting Orwell Permanent Recording on current Channel") 
              os.system("wall %s" % servname)
              cmd = "%s start %s" % (orwell_script,servname)
              self.session.open(Console,_(title),[cmd])
            
    def skipRecordCurrentChannel(self,reason):
        self.session.open(MessageBox,_("Permanent Record Current Channel was canceled, because %s" % reason), MessageBox.TYPE_WARNING)

class OrwellSettings(Screen):
    def __init__(self, session):
        self.session = session
        self.session.openWithCallback(self.askForOrwellSettings,ChoiceBox,_("Orwell Settings Menu"),self.getOrwellSettingsList())

    def askForOrwellSettings(self,setup):
        if setup is None:
            self.skipOrwellSettings(_("no settings submenu choosen"))
        else:
            self.setup = setup[1].rstrip()
            if self.setup is "booton":
               os.system("touch %s" % orwell_enabled)
               self.session.open(MessageBox,("Permanent Recording enabled on boot"),  MessageBox.TYPE_INFO, timeout=5)
            elif self.setup is "bootoff":
               if os.path.exists(orwell_enabled) == True:
                  os.system("rm %s" % orwell_enabled)
               self.session.open(MessageBox,("Permanent Recording disabled on boot"),  MessageBox.TYPE_INFO, timeout=5)
            if self.setup is "standbyon":
               os.system("touch %s" % orwell_always)
               self.session.open(MessageBox,("Permanent Recording enabled during Standby\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            elif self.setup is "standbyoff":
               if os.path.exists(orwell_always) == True:
                  os.system("rm %s" % orwell_always)
               self.session.open(MessageBox,("Permanent Recording disabled during Standby\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            if self.setup is "epgsplitoff":
               os.system("touch %s" % orwell_epgsplit)
               self.session.open(MessageBox,("Permanent Recording disabled EPG split\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            elif self.setup is "epgspliton":
               if os.path.exists(orwell_epgsplit) == True:
                  os.system("rm %s" % orwell_epgsplit)
               self.session.open(MessageBox,("Permanent Recording enabld EPG split\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            if self.setup is "debugon":
               os.system("touch %s" % orwell_debug)
               self.session.open(MessageBox,("Permanent Recording enabled debug info\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            elif self.setup is "debugoff":
               if os.path.exists(orwell_debug) == True:
                  os.system("rm %s" % orwell_debug)
               self.session.open(MessageBox,("Permanent Recording disabled debug info\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
            elif self.setup is "path":
               self.session.openWithCallback(self.askForOrwellPath,ChoiceBox,_("Change Orwell Permanent Recording Filelocation"),self.getOrwellPathList())
            elif self.setup is "limit":
               self.session.openWithCallback(self.askForOrwellLimit,ChoiceBox,_("Size of Orwell Permanent Recording Files"),self.getOrwellLimitList())
            elif self.setup is "number":
               self.session.openWithCallback(self.askForOrwellNumber,ChoiceBox,_("Number of Orwell Permanent Recording Files"),self.getOrwellNumberList())
            elif self.setup is "timeout":
               self.session.openWithCallback(self.askForOrwellTimeout,ChoiceBox,_("Timeout of Orwell Permanent Recording"),self.getOrwellTimeoutList())
            else:
               pass
        
    def askForOrwellLimit(self,limit):
        if limit is None:
            self.skipOrwellSettings(_("no limit choosen"))
        else:
            limitfile = open(orwell_limit, "w")
            limitfile.write(limit[1])
            limitfile.close()
            self.session.open(MessageBox,("Permanent Recording File Size Limit changed\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)
        
    def askForOrwellTimeout(self,timeout):
        if timeout is None:
            self.skipOrwellSettings(_("no timeout choosen"))
        else:
            timeoutfile = open(orwell_timeout, "w")
            timeoutfile.write(timeout[1])
            timeoutfile.close()
            self.session.open(MessageBox,("Permanent Recording Timeout changed\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)

    def askForOrwellNumber(self,number):
        if number is None:
            self.skipOrwellSettings(_("no number choosen"))
        else:
            numberfile = open(orwell_number, "w")
            numberfile.write(number[1])
            numberfile.close()
            self.session.open(MessageBox,("Permanent Recording File Number Limit changed\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)

    def askForOrwellPath(self,path):
        if path is None:
            self.skipOrwellSettings(_("no recording path choosen"))
        else:
            pathfile = open(orwell_path, "w")
            pathfile.write(path[1])
            pathfile.close()
            self.session.open(MessageBox,("Permanent Recording Location changed\nRestart Orwell to activate"),  MessageBox.TYPE_INFO, timeout=5)

    def skipOrwellSettings(self,reason):
        self.session.open(MessageBox,_("command was canceled, because %s") % reason, MessageBox.TYPE_ERROR)
        
    def getOrwellSettingsList(self):
        orwellsetup = []
        orwellsetup.append((_("Change Size of Orwell Recording Files"), "limit"))        
        orwellsetup.append((_("Change Number of Orwell Recording Files"), "number"))        
        orwellsetup.append((_("Change Orwell Recording Timeout"), "timeout"))        
        orwellsetup.append((_("Change Orwell Recording Location"), "path"))        
        if os.path.exists(orwell_epgsplit) == True:
           orwellsetup.append((_("Enable Orwell Permanent Recording EPG split"), "epgspliton"))        
        else:
           orwellsetup.append((_("Disable Orwell Permanent Recording EPG split"), "epgsplitoff"))        
        if os.path.exists(orwell_enabled) == True:
           orwellsetup.append((_("Disable Orwell Permanent Recording on boot"), "bootoff"))        
        else:
           orwellsetup.append((_("Enable Orwell Permanent Recording on boot"), "booton"))        
        if os.path.exists(orwell_always) == True:
           orwellsetup.append((_("Disable Orwell Permanent Recording during Standby"), "standbyoff"))        
        else:
           orwellsetup.append((_("Enable Orwell Permanent Recording during Standby"), "standbyon"))        
        if os.path.exists(orwell_debug) == True:
           orwellsetup.append((_("Disable Orwell Permanent Recording Debugging info"), "debugoff"))        
        else:
           orwellsetup.append((_("Enable Orwell Permanent Recording Debugging info"), "debugon"))        
        return orwellsetup
        
    def getOrwellLimitList(self):
        orwelllimit = []
        orwelllimit.append((_("100 MB"), "100"))        
        orwelllimit.append((_("200 MB"), "200"))        
        orwelllimit.append((_("600 MB"), "600"))        
        orwelllimit.append((_("2.0 GB"), "2000"))        
        orwelllimit.append((_("4.0 GB (default)"), "4000"))        
        orwelllimit.append((_("4.7 GB"), "4700"))        
        orwelllimit.append((_("8.0 GB"), "8000"))        
        orwelllimit.append((_("12.0 GB"), "12000"))        
        orwelllimit.append((_("16.0 GB"), "16000"))        
        orwelllimit.append((_("24.0 GB"), "24000"))        
        return orwelllimit
        
    def getOrwellTimeoutList(self):
        orwelltimeout = []
        orwelltimeout.append((_("2 sec (not recommended)"), "2"))        
        orwelltimeout.append((_("5 sec"), "5"))        
        orwelltimeout.append((_("10 sec (default)"), "10"))        
        orwelltimeout.append((_("15 sec"), "15"))        
        orwelltimeout.append((_("20 sec"), "20"))        
        orwelltimeout.append((_("30 sec"), "30"))        
        orwelltimeout.append((_("60 sec"), "60"))        
        return orwelltimeout

    def getOrwellNumberList(self):
        orwellnumber = []
        orwellnumber.append((_("2"), "2"))        
        orwellnumber.append((_("4 (default)"), "4"))        
        orwellnumber.append((_("8"), "8"))        
        orwellnumber.append((_("12"), "12"))        
        orwellnumber.append((_("16"), "16"))        
        orwellnumber.append((_("24"), "24"))        
        return orwellnumber

    def getOrwellPathList(self):
        orwellpath = []
        orwellpath.append((_("Harddisk (default)"), "/media/hdd"))        
        orwellpath.append((_("CF Card"), "/media/cf"))        
        orwellpath.append((_("USB Stick"), "/media/usb"))        
        return orwellpath
